|License| |PyPI version|

HiOrCo
======

Computing **Hi**\ gher-\ **Or**\ der **Co**-occurrence patterns in
microbial samples.

Installation
~~~~~~~~~~~~

Can be easily installed using **pip**:

::

   pip install hiorco

Usage
~~~~~

As simple as:

::

   hiorco samples.tsv

You can download our example here:
`samples.tsv <https://github.com/cdanielmachado/HiOrCo/raw/master/example/samples.tsv>`__,
and check the documentation for more options and details:

::

   hiorco -h

Credits
~~~~~~~

Daniel Machado, European Molecular Biology Laboratory (EMBL), 2019

.. |License| image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
   :target: https://opensource.org/licenses/Apache-2.0
.. |PyPI version| image:: https://badge.fury.io/py/hiorco.svg
   :target: https://badge.fury.io/py/hiorco
